@@ -176,6 +176,26 @@ def show_archives():
         logging.info(value.name())
 
 
+@click.command()
+@click.argument('issn')
+@transaction.atomic()
+def show_issn(issn):
+    """Show preservation items that match an ISSN"""
+    from constants import archives
+
+    for key, archive_object in archives.items():
+        issns = archive_object.objects.filter(issn=issn)
+
+        for issn_object in issns:
+            logging.info(f'{archive_object.name()} preserves {issn_object}')
+
+        if 'eissn' in archive_object._meta.get_fields():
+            issns = archive_object.objects.filter(eissn=issn)
+
+            for issn_object in issns:
+                logging.info(f'{archive_object.name()} preserves {issn_object}')
+
+
 @click.command()
 @click.argument('archive_name')
 @click.option('--count',
@@ -245,8 +265,7 @@ def import_all():
 
 
 @click.command()
-@click.option('--doi',
-              help='The DOI to lookup for preservation status')
+@click.argument('doi')
 def show_preservation(doi):
     """
     Determine whether a DOI is preserved
@@ -283,6 +302,7 @@ if __name__ == '__main__':
     cli.add_command(random_samples)
     cli.add_command(show_archives)
     cli.add_command(show_cache)
+    cli.add_command(show_issn)
     cli.add_command(show_preservation)
     cli.add_command(stamp_cache_today)
     cli()
