@@ -1,6 +1,6 @@
 from preservationdatabase.models import CarinianaPreservation, \
     ClockssPreservation, HathiPreservation, LockssPreservation, \
-    PKPPreservation, PorticoPreservation
+    OculScholarsPortalPreservation, PKPPreservation, PorticoPreservation
 
 archives = {
     'cariniana': CarinianaPreservation,
@@ -8,5 +8,6 @@ archives = {
     'hathitrust': HathiPreservation,
     'lockss': LockssPreservation,
     'pkp': PKPPreservation,
-    'portico': PorticoPreservation
+    'portico': PorticoPreservation,
+    'ocul': OculScholarsPortalPreservation
 }
