@@ -729,11 +729,19 @@ class OculScholarsPortalPreservation(models.Model):
         if not preserved_item or len(preserved_item) == 0:
             return None, False
 
-        # Portico gives volume formats as follows:
-        # 2013/2014 - v. 2 (1-2)
-        volume_regex = r'v\.\s(\d+)'
+        pi = preserved_item.filter(preserved_volumes=volume)
+
+        if len(pi) > 0:
+            return pi[0], pi[0].preserved
+        else:
+            return None, False
+
+        # OCUL gives volume formats as follows:
+        # v24(1)
+        volume_regex = r'v(\d+)'
 
         for pi in preserved_item:
+            print(pi.preserved_volumes)
             matches = re.findall(volume_regex, pi.preserved_volumes)
 
             volume = str(volume)
